yeelight package
================

This is the autogenerated API documentation. Use it as a reference to the public
API of the project.

yeelight.main module
--------------------

.. automodule:: yeelight.main
    :members:
    :undoc-members:
    :show-inheritance:
